/* Strip out control characters */

#include <stdio.h>

int main() {
        unsigned char a;
        while(!feof(stdin)) {
                a = getc(stdin);
                /* Change this for UTF8 instead of ISO-8859-1 */

                if((a & 0x7f) < 32)
                        printf("<%x>",a);
                else
                        printf("%c",a);

                }
	return 0;
        }


